summaryrefslogtreecommitdiff
path: root/sd/source/ui/inc/taskpane/ToolPanelViewShell.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'sd/source/ui/inc/taskpane/ToolPanelViewShell.hxx')
-rw-r--r--sd/source/ui/inc/taskpane/ToolPanelViewShell.hxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/sd/source/ui/inc/taskpane/ToolPanelViewShell.hxx b/sd/source/ui/inc/taskpane/ToolPanelViewShell.hxx
index fb9d31aa04a1..3ad67a0e7daa 100644
--- a/sd/source/ui/inc/taskpane/ToolPanelViewShell.hxx
+++ b/sd/source/ui/inc/taskpane/ToolPanelViewShell.hxx
@@ -126,7 +126,7 @@ public:
*/
virtual bool RelocateToParentWindow (::Window* pParentWindow);
/// returns <TRUE/> if and only if the given window is the panel anchor window of our ToolPanelDeck
bool IsPanelAnchorWindow( const ::Window& i_rWindow ) const;
/** creates an XUIElement for the given standard panel
@@ -145,7 +145,7 @@ private:
/** The id of the menu in the menu bar/tool box of the parent docking
window.
*/
- USHORT mnMenuId;
+ sal_uInt16 mnMenuId;
/** Create a popup menu. it contains two sections, one for
docking or un-docking the tool panel, one for toggling the
@@ -158,7 +158,7 @@ private:
/** Initialize the task pane view shell if that has not yet been done
- before. If mbIsInitialized is already set to <TRUE/> then this
+ before. If mbIsInitialized is already set to <sal_True/> then this
method returns immediately.
*/
void Initialize (void);
@@ -126,7 +126,7 @@ public:
*/
virtual bool RelocateToParentWindow (::Window* pParentWindow);
- /// returns <TRUE/> if and only if the given window is the panel anchor window of our ToolPanelDeck
+ /// returns <sal_True/> if and only if the given window is the panel anchor window of our ToolPanelDeck
bool IsPanelAnchorWindow( const ::Window& i_rWindow ) const;
/** creates an XUIElement for the given standard panel